@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # Preloaded methods go here.
 
@@ -84,10 +84,11 @@ sub new {
     my $self = {};
     bless( $self, $class );
 
-    $self->{'SSN'}         = $SSN;
-    $self->{'GROUP_ORDER'} = $GROUP_ORDER;
-    $self->{'AD_SSN'}      = $ADVERTISING_SSN;
-    $self->{'BAD_COMBO'}   = $BAD_COMBO;
+    $self->{'SSN'}                = $SSN;
+    $self->{'GROUP_ORDER'}        = $GROUP_ORDER;
+    $self->{'AD_SSN'}             = $ADVERTISING_SSN;
+    $self->{'BAD_COMBO'}          = $BAD_COMBO;
+    $self->{'BAD_COMBO_IGNORE'}   = $args->{'ignore_bad_combo'} || 0;
 
     return $self;
 }
@@ -119,7 +120,7 @@ sub valid_ssn {
 	# Some groups are invalid with certain areas.
 	# Rhyme and reason are not a part of the SSA.
 
-	if (in_array($area . $group, $self->{'BAD_COMBO'})) {
+	if (!$self->{'BAD_COMBO_IGNORE'} && in_array($area . $group, $self->{'BAD_COMBO'})) {
 		$self->{'ERROR'} = 'Invalid area/group combo';
 		return 0;
 	}
@@ -161,12 +162,17 @@ sub valid_group {
         $group = substr( $group, 3, 2 );
         return 0 if $group eq '00';
 
-				if (in_array($area . $group, $self->{'BAD_COMBO'})) {
+				if (!$self->{'BAD_COMBO_IGNORE'} && in_array($area . $group, $self->{'BAD_COMBO'})) {
 					$self->{'ERROR'} = 'Invalid area/group combo';
 					return 0;
 				}
 
         if ( defined $self->{'SSN'}{$area}{'highgroup'} ) {
+						# We're igno
+					  if ($self->{'BAD_COMBO_IGNORE'} && in_array($area . $group, $self->{'BAD_COMBO'})) {
+							return 1;
+						}
+
             return in_array( $group,
                 $self->get_group_range( $self->{'SSN'}{$area}{'highgroup'} ) );
         }
@@ -323,6 +329,10 @@ SSN::Validate - Perl extension do SSN Validation
 
   my $ssn = new SSN::Validate;
 
+  or 
+
+  my $ssn = SSN::Validate->new({'ignore_bad_combo' => 1});
+
   if ($ssn->valid_ssn("123-45-6789")) {
     print "It's a valid SSN";
   }
@@ -356,6 +366,12 @@ AAAA-GG-SSSS
 
 =over 4
 
+=item new();
+
+You can pass an arg of 'ignore_bad_combo' as true if you wish to ignore
+any defined bad AAAA-GG combinations. Things will be on the list until
+I see otherwise on the SSA website or some other means of proof.
+
 =item valid_ssn($ssn);
 
 The SSN can be of any format (111-11-1111, 111111111, etc...). All non-digits
@@ -407,8 +423,8 @@ it.. or will return an empty string.
 
 * Find out state(s) for areas which aren't known right now.
 
-* Incorporate SSA scraping to update module data (script from Benjamin
-  R. Ginter)
+* Automate this module almost as completely as possible for
+  distribution. 
 
 * Consider SSN::Validate::SSDI for Social Security Death Index (SSDI)
 
@@ -416,7 +432,6 @@ it.. or will return an empty string.
 issued, AREAs as valid. The SSA considers them invalid, but someone may
 want to have the included.
 
-
 =head2 EXPORT
 
 None by default.
@@ -448,7 +463,7 @@ modify it under the same terms as Perl itself.
 
 L<http://www.ssa.gov/foia/stateweb.html>,
 L<http://www.irs.gov/pub/irs-utl/1346atta.pdf>,
-L<http://www.ssa.gov/foia/highgroup.htm>.
+L<http://www.ssa.gov/employer/highgroup.txt>.
 
 =cut
 
@@ -546,27 +561,29 @@ __DATA__
 #765	?? Unknown
 900-999 ?? Taxpayer Identification Number
 ## high groups
-001,98
-002,98
-003,96
-004,04
-005,04
+# This is scraped directly from
+# http://www.ssa.gov/employer/highgroup.txt
+001,02
+002,02
+003,98
+004,06
+005,06
 006,04
-007,02
-008,86
-009,86
-010,86
-011,86
-012,86
-013,86
-014,86
-015,86
-016,86
-017,86
-018,86
-019,86
-020,86
-021,86
+007,04
+008,88
+009,88
+010,88
+011,88
+012,88
+013,88
+014,88
+015,88
+016,88
+017,88
+018,88
+019,88
+020,88
+021,88
 022,86
 023,86
 024,86
@@ -575,66 +592,66 @@ __DATA__
 027,86
 028,86
 029,86
-030,84
-031,84
-032,84
-033,84
-034,84
+030,86
+031,86
+032,86
+033,86
+034,86
 035,70
 036,70
-037,68
-038,68
+037,70
+038,70
 039,68
-040,06
-041,06
-042,06
+040,08
+041,08
+042,08
 043,06
-044,04
-045,04
-046,04
-047,04
-048,04
-049,04
-050,92
-051,92
-052,92
-053,92
-054,92
-055,92
-056,92
-057,92
-058,92
-059,92
-060,92
-061,92
-062,92
-063,92
-064,92
-065,92
-066,92
-067,92
-068,92
-069,92
-070,92
-071,92
-072,92
-073,92
-074,92
-075,92
-076,92
-077,92
-078,92
-079,92
-080,92
-081,92
-082,92
-083,92
-084,92
-085,92
-086,92
-087,92
-088,92
-089,92
+044,06
+045,06
+046,06
+047,06
+048,06
+049,06
+050,94
+051,94
+052,94
+053,94
+054,94
+055,94
+056,94
+057,94
+058,94
+059,94
+060,94
+061,94
+062,94
+063,94
+064,94
+065,94
+066,94
+067,94
+068,94
+069,94
+070,94
+071,94
+072,94
+073,94
+074,94
+075,94
+076,94
+077,94
+078,94
+079,94
+080,94
+081,94
+082,94
+083,94
+084,94
+085,94
+086,94
+087,94
+088,94
+089,94
 090,92
 091,92
 092,92
@@ -661,74 +678,74 @@ __DATA__
 113,92
 114,92
 115,92
-116,90
-117,90
-118,90
-119,90
-120,90
-121,90
-122,90
-123,90
-124,90
-125,90
-126,90
-127,90
-128,90
-129,90
-130,90
-131,90
-132,90
-133,90
-134,90
-135,13
-136,13
-137,13
-138,13
-139,13
-140,13
-141,13
-142,13
-143,11
-144,11
-145,11
-146,11
-147,11
-148,11
-149,11
-150,11
-151,11
-152,11
-153,11
-154,11
-155,11
-156,11
-157,11
-158,11
-159,80
-160,80
-161,80
-162,80
-163,80
-164,80
-165,80
-166,80
-167,80
-168,80
-169,80
-170,80
-171,80
-172,80
-173,80
-174,80
-175,80
-176,80
-177,80
-178,80
-179,80
-180,80
-181,80
-182,80
-183,80
+116,92
+117,92
+118,92
+119,92
+120,92
+121,92
+122,92
+123,92
+124,92
+125,92
+126,92
+127,92
+128,92
+129,92
+130,92
+131,92
+132,92
+133,92
+134,92
+135,15
+136,15
+137,15
+138,15
+139,15
+140,15
+141,15
+142,15
+143,15
+144,13
+145,13
+146,13
+147,13
+148,13
+149,13
+150,13
+151,13
+152,13
+153,13
+154,13
+155,13
+156,13
+157,13
+158,13
+159,82
+160,82
+161,82
+162,82
+163,82
+164,82
+165,82
+166,82
+167,82
+168,82
+169,82
+170,82
+171,82
+172,82
+173,82
+174,82
+175,82
+176,82
+177,82
+178,82
+179,82
+180,82
+181,82
+182,82
+183,82
 184,80
 185,80
 186,80
@@ -756,31 +773,31 @@ __DATA__
 208,80
 209,80
 210,80
-211,78
-212,67
-213,67
-214,67
-215,67
-216,67
-217,65
-218,65
-219,65
-220,65
-221,98
-222,96
-223,97
-224,97
-225,97
-226,95
-227,95
-228,95
-229,95
-230,95
-231,95
-232,49
-233,49
-234,49
-235,49
+211,80
+212,71
+213,71
+214,71
+215,71
+216,71
+217,69
+218,69
+219,69
+220,69
+221,02
+222,98
+223,99
+224,99
+225,99
+226,99
+227,99
+228,99
+229,99
+230,99
+231,99
+232,51
+233,51
+234,51
+235,51
 236,49
 237,99
 238,99
@@ -813,12 +830,12 @@ __DATA__
 265,99
 266,99
 267,99
-268,08
-269,08
-270,08
-271,08
-272,08
-273,08
+268,11
+269,11
+270,11
+271,11
+272,11
+273,11
 274,08
 275,08
 276,08
@@ -830,54 +847,54 @@ __DATA__
 282,08
 283,08
 284,08
-285,06
-286,06
-287,06
-288,06
-289,06
-290,06
-291,06
-292,06
-293,06
-294,06
-295,06
-296,06
-297,06
-298,06
-299,06
-300,06
-301,06
-302,06
-303,27
-304,27
-305,27
-306,27
+285,08
+286,08
+287,08
+288,08
+289,08
+290,08
+291,08
+292,08
+293,08
+294,08
+295,08
+296,08
+297,08
+298,08
+299,08
+300,08
+301,08
+302,08
+303,29
+304,29
+305,29
+306,29
 307,27
-308,25
-309,25
-310,25
-311,25
-312,25
-313,25
-314,25
-315,25
-316,25
-317,25
-318,02
-319,02
-320,02
-321,02
-322,02
-323,02
-324,02
-325,02
-326,02
-327,02
-328,02
-329,02
-330,02
-331,02
-332,02
+308,27
+309,27
+310,27
+311,27
+312,27
+313,27
+314,27
+315,27
+316,27
+317,27
+318,04
+319,04
+320,04
+321,04
+322,04
+323,04
+324,04
+325,04
+326,04
+327,04
+328,04
+329,04
+330,04
+331,04
+332,04
 333,02
 334,02
 335,02
@@ -890,90 +907,90 @@ __DATA__
 342,02
 343,02
 344,02
-345,98
-346,98
-347,98
-348,98
-349,98
-350,98
-351,98
-352,98
-353,98
-354,98
-355,98
-356,98
-357,98
-358,98
-359,98
-360,98
-361,98
-362,29
-363,29
-364,29
-365,29
-366,29
-367,29
-368,29
-369,29
-370,29
-371,29
-372,29
-373,29
+345,02
+346,02
+347,02
+348,02
+349,02
+350,02
+351,02
+352,02
+353,02
+354,02
+355,02
+356,02
+357,02
+358,02
+359,02
+360,02
+361,02
+362,31
+363,31
+364,31
+365,31
+366,31
+367,31
+368,31
+369,31
+370,31
+371,31
+372,31
+373,31
 374,29
 375,29
-376,27
-377,27
-378,27
-379,27
-380,27
-381,27
-382,27
-383,27
-384,27
-385,27
-386,27
-387,23
-388,23
-389,23
-390,23
-391,23
-392,23
-393,23
-394,23
-395,23
-396,23
+376,29
+377,29
+378,29
+379,29
+380,29
+381,29
+382,29
+383,29
+384,29
+385,29
+386,29
+387,25
+388,25
+389,25
+390,25
+391,25
+392,25
+393,25
+394,25
+395,25
+396,25
 397,23
 398,23
-399,21
-400,61
-401,61
-402,61
-403,59
-404,59
-405,59
-406,59
-407,59
-408,95
-409,95
-410,95
-411,95
-412,95
-413,95
-414,93
-415,93
-416,55
-417,55
-418,55
-419,55
-420,55
-421,55
-422,55
-423,55
-424,53
-425,93
-426,93
-427,93
-428,93
+399,23
+400,63
+401,63
+402,63
+403,63
+404,63
+405,61
+406,61
+407,61
+408,99
+409,99
+410,99
+411,97
+412,97
+413,97
+414,97
+415,97
+416,57
+417,57
+418,57
+419,57
+420,57
+421,57
+422,57
+423,57
+424,57
+425,97
+426,95
+427,95
+428,95
 429,99
 430,99
 431,99
@@ -986,14 +1003,14 @@ __DATA__
 438,99
 439,99
 440,19
-441,17
-442,17
-443,17
-444,17
-445,17
-446,17
-447,17
-448,17
+441,19
+442,19
+443,19
+444,19
+445,19
+446,19
+447,19
+448,19
 449,99
 450,99
 451,99
@@ -1013,59 +1030,59 @@ __DATA__
 465,99
 466,99
 467,99
-468,43
-469,43
-470,43
-471,43
-472,43
-473,41
-474,41
-475,41
-476,41
-477,41
-478,33
-479,33
-480,33
+468,45
+469,45
+470,45
+471,45
+472,45
+473,45
+474,45
+475,45
+476,43
+477,43
+478,35
+479,35
+480,35
 481,33
 482,33
-483,31
-484,31
-485,31
-486,21
+483,33
+484,33
+485,33
+486,23
 487,21
 488,21
-489,19
-490,19
-491,19
-492,19
-493,19
-494,19
-495,19
-496,19
-497,19
-498,19
-499,19
-500,19
-501,29
+489,21
+490,21
+491,21
+492,21
+493,21
+494,21
+495,21
+496,21
+497,21
+498,21
+499,21
+500,21
+501,31
 502,29
-503,35
-504,33
-505,47
-506,45
-507,45
-508,45
-509,23
+503,37
+504,35
+505,49
+506,47
+507,47
+508,47
+509,25
 510,23
-511,21
-512,21
-513,21
-514,21
-515,21
-516,39
-517,37
-518,67
-519,65
-520,47
+511,23
+512,23
+513,23
+514,23
+515,23
+516,41
+517,39
+518,71
+519,69
+520,49
 521,99
 522,99
 523,99
@@ -1076,20 +1093,20 @@ __DATA__
 528,99
 529,99
 530,99
-531,53
-532,51
-533,51
-534,51
-535,51
-536,51
-537,51
-538,51
-539,51
-540,65
-541,65
-542,63
-543,63
-544,63
+531,55
+532,55
+533,55
+534,55
+535,55
+536,55
+537,55
+538,53
+539,53
+540,67
+541,67
+542,67
+543,67
+544,67
 545,99
 546,99
 547,99
@@ -1119,20 +1136,20 @@ __DATA__
 571,99
 572,99
 573,99
-574,39
-575,97
-576,95
-577,35
-578,35
-579,35
+574,41
+575,99
+576,99
+577,39
+578,37
+579,37
 580,35
 581,99
 582,99
 583,99
 584,99
 585,99
-586,51
-587,91
+586,55
+587,95
 589,99
 590,99
 591,99
@@ -1140,100 +1157,102 @@ __DATA__
 593,99
 594,99
 595,99
-596,74
-597,72
-598,72
-599,72
+596,78
+597,76
+598,76
+599,76
 600,99
 601,99
-602,39
-603,39
-604,39
-605,39
-606,39
-607,39
-608,39
-609,39
-610,39
-611,39
-612,39
-613,39
-614,39
-615,39
-616,39
-617,39
-618,39
-619,39
-620,39
-621,39
-622,39
-623,39
-624,39
-625,39
-626,39
-627,88
-628,88
-629,86
-630,86
-631,86
-632,86
-633,86
-634,86
-635,86
-636,86
-637,86
-638,86
-639,86
-640,86
-641,86
-642,86
-643,86
-644,86
-645,86
-646,72
-647,70
-648,32
-649,30
-650,28
-651,28
-652,26
-653,26
-654,16
-655,16
-656,14
-657,14
-658,14
-659,07
-660,07
-661,07
-662,07
-663,07
-664,07
-665,07
-667,20
-668,20
-669,18
-670,18
-671,18
-672,18
-673,18
-674,18
-675,18
-676,05
-677,05
-678,05
-679,03
-680,50
-681,01
-682,01
-683,01
-684,01
-685,01
-686,01
-687,03
-688,01
-689,01
-690,01
+602,49
+603,49
+604,49
+605,49
+606,49
+607,49
+608,49
+609,47
+610,47
+611,47
+612,47
+613,47
+614,47
+615,47
+616,47
+617,47
+618,47
+619,47
+620,47
+621,47
+622,47
+623,47
+624,47
+625,47
+626,47
+627,94
+628,94
+629,94
+630,94
+631,94
+632,94
+633,94
+634,94
+635,94
+636,94
+637,94
+638,94
+639,92
+640,92
+641,92
+642,92
+643,92
+644,92
+645,92
+646,80
+647,78
+648,36
+649,34
+650,34
+651,34
+652,32
+653,32
+654,20
+655,18
+656,18
+657,18
+658,18
+659,10
+660,10
+661,10
+662,09
+663,09
+664,09
+665,09
+667,24
+668,24
+669,24
+670,24
+671,24
+672,24
+673,24
+674,22
+675,22
+676,09
+677,09
+678,07
+679,07
+680,62
+681,07
+682,05
+683,05
+684,05
+685,05
+686,05
+687,05
+688,05
+689,05
+690,05
+691,01
+692,01
 700,18
 701,18
 702,18
@@ -1263,14 +1282,21 @@ __DATA__
 726,18
 727,10
 728,14
-729,01
-730,01
-764,32
-765,32
-766,22
-767,22
-768,22
-769,22
-770,20
+729,03
+730,03
+731,03
+732,03
+733,03
+750,01
+751,01
+764,48
+765,48
+766,36
+767,36
+768,34
+769,34
+770,34
+771,34
+772,34
 900,70-80 ## Individual Taxpayer Identification Number
 900,93-93 ## Adoption Taxpayer Identification Number
